@@ -12,13 +12,17 @@ from uuid import UUID
 EMBER_MUG = "Ember Ceramic Mug"
 EMBER_CUP = "Ember Cup"
 EMBER_CUP_2 = "Ember Cup 2"
+EMBER_TRAVEL_MUG_SHORT = "Ember Travel M"
 EMBER_TRAVEL_MUG = "Ember Travel Mug"
+EMBER_TRAVEL_MUG_2 = "Ember Travel Mug 2"
 
 EMBER_BLUETOOTH_NAMES: tuple[str, ...] = (
     EMBER_MUG,
     EMBER_CUP,
     EMBER_CUP_2,
     EMBER_TRAVEL_MUG,
+    EMBER_TRAVEL_MUG_SHORT,
+    EMBER_TRAVEL_MUG_2,
 )
 
 # Format for all the mug's Bluetooth UUIDs
@@ -45,7 +49,7 @@ class MugCharacteristic(IntEnum):
     TEMPERATURE_UNIT = 4
     # Level (Between 0 -> 30 ?) 30 100% ?
     LIQUID_LEVEL = 5
-    # Date/Time (Read/Write)
+    # Current date and time zone? (Read/Write)
     DATE_TIME_AND_ZONE = 6
     # Battery Info (Read)
     BATTERY = 7
@@ -76,7 +80,8 @@ class MugCharacteristic(IntEnum):
     # RGBA Colour of LED (Read/Write)
     LED = 20
     # Service
-    SERVICE = 13858
+    TRAVEL_MUG_SERVICE = 13857
+    STANDARD_SERVICE = 13858
 
     @cached_property
     def uuid(self) -> UUID:
@@ -84,7 +89,7 @@ class MugCharacteristic(IntEnum):
         return UUID(UUID_TEMPLATE.format(self.value))
 
     def __str__(self) -> str:
-        """String representation is the UUID."""
+        """Convert UUID to string value."""
         return str(self.uuid)
 
 
@@ -106,10 +111,28 @@ class LiquidState(IntEnum):
         return LIQUID_STATE_LABELS[self.value]
 
     def __str__(self) -> str:
-        """String is the label."""
+        """Return label for display."""
         return self.label
 
 
+class VolumeLevel(str, Enum):
+    """Class to manage volume levels."""
+
+    LOW = "low"
+    MEDIUM = "medium"
+    HIGH = "high"
+
+    @classmethod
+    def from_state(cls, state: int) -> VolumeLevel:
+        """Build Volume level from int value."""
+        return {0: cls.LOW, 1: cls.MEDIUM, 2: cls.HIGH}[state]
+
+    @cached_property
+    def state(self) -> int:
+        """Get int value from value."""
+        return {self.LOW: 0, self.MEDIUM: 1, self.HIGH: 2}[self]
+
+
 # Push event codes
 class PushEvent(IntEnum):
     """IDs for Push Events."""
@@ -145,20 +168,21 @@ PUSH_EVENT_BATTERY_IDS = [
 
 # Labels for formatting attributes
 ATTR_LABELS = {
-    'name': 'Mug Name',
-    'meta': 'Meta',
-    'battery': 'Battery',
-    'firmware': 'Firmware',
-    'led_colour': 'LED Colour',
-    'liquid_state': 'Liquid State',
-    'liquid_level': 'Liquid Level',
-    'current_temp': 'Current Temp',
-    'target_temp': 'Target Temp',
-    'use_metric': 'Use Metric',
-    'dsk': 'DSK',
-    'udsk': 'UDSK',
-    'date_time_zone': 'Date Time + Time Zone',
-    'battery_voltage': 'Voltage',
+    "name": "Mug Name",
+    "meta": "Meta",
+    "battery": "Battery",
+    "firmware": "Firmware",
+    "led_colour": "LED Colour",
+    "liquid_state": "Liquid State",
+    "liquid_level": "Liquid Level",
+    "current_temp": "Current Temp",
+    "target_temp": "Target Temp",
+    "use_metric": "Use Metric",
+    "dsk": "DSK",
+    "udsk": "UDSK",
+    "date_time_zone": "Date Time + Time Zone",
+    "battery_voltage": "Voltage",
+    "volume_level": "Volume Level",
 }
 
 # Attributes
@@ -179,11 +203,11 @@ UPDATE_ATTRS = {
     "liquid_level",
     "liquid_state",
 }
-TRAVEL_MUG_ATTRS = {"battery_voltage"}
-EXTRA_ATTRS = {'dsk', 'udsk', 'battery_voltage', 'date_time_zone'}
+EXTRA_ATTRS = {"dsk", "udsk", "battery_voltage", "date_time_zone"}
 
 # Validation
 MUG_NAME_REGEX = re.compile(r"^[A-Za-z0-9,.\[\]#()!\"\';:|\-_+<>%= ]{1,16}$")
+MUG_NAME_PATTERN = MUG_NAME_REGEX.pattern
 MAC_ADDRESS_REGEX = re.compile(r"^([0-9A-Fa-f]{2}:){5}([0-9A-Fa-f]{2})$")
 
 IS_LINUX = platform.system() == "Linux"
