@@ -3,13 +3,15 @@ from __future__ import annotations
 
 import asyncio
 import logging
-from typing import TYPE_CHECKING, Any, Callable
+from typing import TYPE_CHECKING, Any
 
 from bleak import BleakScanner
 
 from .consts import EMBER_BLUETOOTH_NAMES, IS_LINUX, MugCharacteristic
 
 if TYPE_CHECKING:
+    from collections.abc import Callable
+
     from bleak.backends.device import BLEDevice
     from bleak.backends.scanner import AdvertisementData
 
@@ -20,14 +22,16 @@ logger = logging.getLogger(__name__)
 def build_scanner_kwargs(adapter: str | None = None) -> dict[str, Any]:
     """Add Adapter to kwargs for scanner if specified and using BlueZ."""
     if adapter and IS_LINUX is not True:
-        raise ValueError('The adapter option is only valid for the Linux BlueZ Backend.')
-    return {'adapter': adapter} if adapter else {}
+        msg = "The adapter option is only valid for the Linux BlueZ Backend."
+        raise ValueError(msg)
+    return {"adapter": adapter} if adapter else {}
 
 
 async def discover_mugs(mac: str | None = None, adapter: str | None = None, wait: int = 5) -> list[BLEDevice]:
     """Discover new mugs in pairing mode."""
     scanner_kwargs = build_scanner_kwargs(adapter)
-    async with BleakScanner(service_uuids=[str(MugCharacteristic.SERVICE)], **scanner_kwargs) as scanner:
+    service_uuids = [str(uuid) for uuid in (MugCharacteristic.STANDARD_SERVICE, MugCharacteristic.TRAVEL_MUG_SERVICE)]
+    async with BleakScanner(service_uuids=service_uuids, **scanner_kwargs) as scanner:
         await asyncio.sleep(wait)
         if mac:
             mac = mac.lower()
@@ -43,7 +47,7 @@ def build_find_filter(mac: str | None = None) -> Callable:
         """Filter by mac if specified else just check the name."""
         if mac is not None and device.address.lower() != mac:
             return False
-        return device.name.lower() in known_names
+        return bool(device.name and device.name.lower() in known_names)
 
     return mug_filter
 
